==> gcc-4.1.1.tar.bz2: gcc-4.1.1/libjava/classpath/org/omg/PortableInterceptor/ORBInitInfoPackage/InvalidName.java <==
/* InvalidName.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.PortableInterceptor.ORBInitInfoPackage;

import org.omg.CORBA.UserException;
import org.omg.CORBA.portable.IDLEntity;

import java.io.Serializable;

/**
 * This exception is raised by methods in
 * {@link org.omg.PortableInterceptor.ORBInitInfoOperations} on the attempt to
 * register or resolve an invalid name like empty string. The already
 * registered names (including the default names, defined by OMG) are also
 * invalid for registration.
 *
 * @author Audrius Meskauskas, Lithiania (AudriusA@Bioinformatics.org)
 */
public class InvalidName extends UserException implements IDLEntity,
  Serializable
{
  /**
   * Use serialVersionUID (v1.4) for interoperability.
   */
  private static final long serialVersionUID = -4599417794753377115L;

  /**
   * Create InvalidName with no explaining message.
   */
  public InvalidName()
  {
  }

  /**
   * Create the InvalidName with explaining message.
   *
   * @param why a string, explaining, why the name is invalid.
   */
  public InvalidName(String why)
  {
    super(why);
  }
}

==> gcc-5.2.0.tar.bz2: gcc-5.2.0/libjava/classpath/org/omg/PortableInterceptor/ORBInitInfoPackage/InvalidName.java <==
/* InvalidName.java --
   Copyright (C) 2005, 2006 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.PortableInterceptor.ORBInitInfoPackage;

import org.omg.CORBA.UserException;
import org.omg.CORBA.portable.IDLEntity;

import java.io.Serializable;

/**
 * This exception is raised by methods in
 * {@link org.omg.PortableInterceptor.ORBInitInfoOperations} on the attempt to
 * register or resolve an invalid name like empty string. The already
 * registered names (including the default names, defined by OMG) are also
 * invalid for registration.
 *
 * @author Audrius Meskauskas, Lithiania (AudriusA@Bioinformatics.org)
 */
public final class InvalidName extends UserException implements IDLEntity,
  Serializable
{
  /**
   * Use serialVersionUID (v1.4) for interoperability.
   */
  private static final long serialVersionUID = -4599417794753377115L;

  /**
   * Create InvalidName with no explaining message.
   */
  public InvalidName()
  {
  }

  /**
   * Create the InvalidName with explaining message.
   *
   * @param why a string, explaining, why the name is invalid.
   */
  public InvalidName(String why)
  {
    super(why);
  }
}
